==> haskell-th-env-0.1.1-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-env.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-env
version:              0.1.1
visibility:           public
id:                   th-env-0.1.1-G47ELLjQX1Q3fLhb9M1pFQ
key:                  th-env-0.1.1-G47ELLjQX1Q3fLhb9M1pFQ
license:              BSD-3-Clause
maintainer:           dima@dzhus.org
author:               Dmitry Dzhus
homepage:             https://github.com/dzhus/th-env#readme
synopsis:
    Template Haskell splices that expand to an environment variable

description:
    TH splices that expand to an environment variable value. Can be used to embed build-time parameters in your application.

category:             Template Haskell
abi:                  4885972103a01daea5582e51ddbdd149
exposed:              True
exposed-modules:      Language.Haskell.TH.Env
hidden-modules:       Paths_th_env
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-env
hs-libraries:         HSth-env-0.1.1-G47ELLjQX1Q3fLhb9M1pFQ
depends:
    base-4.17.2.1 template-haskell-2.19.0.0
    th-compat-0.1.6-8cPy3R6D3MnDEd1IlvsIZR

haddock-interfaces:   /usr/share/doc/haskell-th-env/html/th-env.haddock
haddock-html:         /usr/share/doc/haskell-th-env/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-env-0.1.1-150-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-env.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-env
version:              0.1.1
visibility:           public
id:                   th-env-0.1.1-KcpGTp4ej868uLCOek9pcr
key:                  th-env-0.1.1-KcpGTp4ej868uLCOek9pcr
license:              BSD-3-Clause
maintainer:           dima@dzhus.org
author:               Dmitry Dzhus
homepage:             https://github.com/dzhus/th-env#readme
synopsis:
    Template Haskell splices that expand to an environment variable

description:
    TH splices that expand to an environment variable value. Can be used to embed build-time parameters in your application.

category:             Template Haskell
abi:                  fcb4d5837ca6be7e0c426b1bfb980c22
exposed:              True
exposed-modules:      Language.Haskell.TH.Env
hidden-modules:       Paths_th_env
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-env
hs-libraries:         HSth-env-0.1.1-KcpGTp4ej868uLCOek9pcr
depends:
    base-4.17.2.1 template-haskell-2.19.0.0
    th-compat-0.1.6-XZ9SculvvuE8b09A0WST4

haddock-interfaces:   /usr/share/doc/haskell-th-env/html/th-env.haddock
haddock-html:         /usr/share/doc/haskell-th-env/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
